source_ip_for

Function source_ip_for 

pub fn source_ip_for(url: &Url) -> Result<IpAddr>
Determines which IpAddr is used to contact the given address encoded in a Url with as scheme either tcp or udp. The port of the url must be specified, but the fragment, query, username and password cannot be set, and path must be trivial.